@@ -1340,6 +1340,10 @@ func (m *MockRuns) ForceExecute(ctx context.Context, runID string) error {
 	panic("implement me")
 }
 
+func (m *MockRuns) ListForOrganization(ctx context.Context, organization string, options *tfe.RunListForOrganizationOptions) (*tfe.OrganizationRunList, error) {
+	panic("not implemented")
+}
+
 func (m *MockRuns) Discard(ctx context.Context, runID string, options tfe.RunDiscardOptions) error {
 	m.Lock()
 	defer m.Unlock()
@@ -1450,6 +1454,10 @@ func (m *MockStateVersions) Upload(ctx context.Context, workspaceID string, opti
 	return m.Create(ctx, workspaceID, createOptions)
 }
 
+func (m *MockStateVersions) UploadSanitizedState(ctx context.Context, sanitizedStateUploadURL *string, sanitizedState []byte) error {
+	panic("not implemented")
+}
+
 func (m *MockStateVersions) Read(ctx context.Context, svID string) (*tfe.StateVersion, error) {
 	return m.ReadWithOptions(ctx, svID, nil)
 }
@@ -1571,6 +1579,11 @@ func (m *MockVariables) List(ctx context.Context, workspaceID string, options *t
 	return vl, nil
 }
 
+func (m *MockVariables) ListAll(ctx context.Context, workspaceID string, options *tfe.VariableListOptions) (*tfe.VariableList, error) {
+	vl := m.workspaces[workspaceID]
+	return vl, nil
+}
+
 func (m *MockVariables) Create(ctx context.Context, workspaceID string, options tfe.VariableCreateOptions) (*tfe.Variable, error) {
 	v := &tfe.Variable{
 		ID:       GenerateID("var-"),
@@ -2018,6 +2031,22 @@ func (m *MockWorkspaces) DeleteDataRetentionPolicy(ctx context.Context, workspac
 	panic("not implemented")
 }
 
+func (m *MockWorkspaces) ListTagBindings(ctx context.Context, workspaceID string) ([]*tfe.TagBinding, error) {
+	panic("not implemented")
+}
+
+func (m *MockWorkspaces) ListEffectiveTagBindings(ctx context.Context, workspaceID string) ([]*tfe.EffectiveTagBinding, error) {
+	panic("not implemented")
+}
+
+func (m *MockWorkspaces) AddTagBindings(ctx context.Context, workspaceID string, options tfe.WorkspaceAddTagBindingsOptions) ([]*tfe.TagBinding, error) {
+	panic("not implemented")
+}
+
+func (m *MockWorkspaces) DeleteAllTagBindings(ctx context.Context, workspaceID string) error {
+	panic("not implemented")
+}
+
 const alphanumeric = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789"
 
 func GenerateID(s string) string {
